==> jc-1.4.0.tar.gz: java/text/Annotation.c <==
// public class java.text.Annotation

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 2441695b7a69eb12 java_lang_VMClass
// @dep_class 687d454d2df09fc5 java_text_Annotation

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header java_lang_VMClass
// @dep_header java_text_Annotation

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "java/lang/VMClass.h"
#include "java/text/Annotation.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.Object attrib
static _jc_field _jc_java_text_Annotation$field_info$attrib = {
	.name=		"attrib",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_java_text_Annotation$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_text_Annotation$object, refs[-1].java_text_Annotation.attrib),
};

// Fields
static _jc_field *const _jc_java_text_Annotation$fields[] = {
	&_jc_java_text_Annotation$field_info$attrib
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object)
//

static _jc_linenum _jc_java_text_Annotation$linenum_table$_init$3fddd28dadb712ab[];

static const unsigned char _jc_java_text_Annotation$param_ptypes$_init$3fddd28dadb712ab[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_text_Annotation$param_types$_init$3fddd28dadb712ab[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_text_Annotation$method_info$_init$3fddd28dadb712ab = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_java_text_Annotation$type,
	.param_types=		&_jc_java_text_Annotation$param_types$_init$3fddd28dadb712ab,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_text_Annotation$param_ptypes$_init$3fddd28dadb712ab,
	.signature_hash=	_JC_JLONG(0x3fddd28dadb712ab),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_text_Annotation$method$_init$3fddd28dadb712ab,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_text_Annotation$linenum_table$_init$3fddd28dadb712ab
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_text_Annotation, _init$3fddd28dadb712ab);

void
_jc_java_text_Annotation$method$_init$3fddd28dadb712ab(_jc_env *const env, _jc_java_text_Annotation$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_java_text_Annotation$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(77);				// 0
	_JC_REF_FIELD(env, r0, java_text_Annotation, attrib) = r1;
	_JC_LINE_NUMBER(78);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object getValue()
//

static _jc_linenum _jc_java_text_Annotation$linenum_table$getValue$6f8b281a5ffcc94f[];

static const unsigned char _jc_java_text_Annotation$param_ptypes$getValue$6f8b281a5ffcc94f[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_text_Annotation$method_info$getValue$6f8b281a5ffcc94f = {
	.name=			"getValue",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_java_text_Annotation$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_text_Annotation$param_ptypes$getValue$6f8b281a5ffcc94f,
	.signature_hash=	_JC_JLONG(0x6f8b281a5ffcc94f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_text_Annotation$method$getValue$6f8b281a5ffcc94f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_text_Annotation$vtable, java_text_Annotation.getValue$6f8b281a5ffcc94f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_text_Annotation$linenum_table$getValue$6f8b281a5ffcc94f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_text_Annotation, getValue$6f8b281a5ffcc94f);

_jc_java_lang_Object$object *
_jc_java_text_Annotation$method$getValue$6f8b281a5ffcc94f(_jc_env *const env, _jc_java_text_Annotation$object *this)
{
	struct _jc_java_text_Annotation$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(95);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_text_Annotation, attrib);
	return r1;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_java_text_Annotation$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_java_text_Annotation$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_text_Annotation$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_text_Annotation$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_text_Annotation$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_text_Annotation$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_text_Annotation$vtable, java_text_Annotation.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_text_Annotation$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_text_Annotation, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_java_text_Annotation$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_java_text_Annotation$object *this)
{
	struct _jc_java_text_Annotation$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_Class$object *r2;
	struct _jc_java_lang_String$object *r3;
	struct _jc_java_lang_Object$object *r4;
	struct _jc_java_lang_String$object *r5;
	struct _jc_java_lang_String$object *r6;
	_jc_char_array *r7;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(109);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r7 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r7;
	r2 = _JC_INVOKE_NONVIRTUAL(env, java_lang_Object, getClass$1f1ddb358c8ea7be, 0, r0);
	_JC_EXPLICIT_NULL_CHECK(env, r2);
	r5 = _JC_INVOKE_STATIC(env, java_lang_VMClass, getName$7a04fe8e1a654d36, 0, r2);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r5);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "[value="));
	r4 = _JC_REF_FIELD(env, r0, java_text_Annotation, attrib);
	r3 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r4);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r3);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$9450b16e89f0618d, 0, r1, 93);
	r6 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r6, r1);
	return r6;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_text_Annotation$methods[] = {
	&_jc_java_text_Annotation$method_info$_init$3fddd28dadb712ab,
	&_jc_java_text_Annotation$method_info$getValue$6f8b281a5ffcc94f,
	&_jc_java_text_Annotation$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_text_Annotation$instanceof_hash_bucket_69[] = {
	&_jc_java_text_Annotation$type,
	_JC_NULL
};
static _jc_type *const _jc_java_text_Annotation$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_text_Annotation$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[69]=	_jc_java_text_Annotation$instanceof_hash_bucket_69,
	[113]=	_jc_java_text_Annotation$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_text_Annotation$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "java/lang/VMClass",	_JC_JLONG(0x2441695b7a69eb12) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_text_Annotation$vtype _jc_java_text_Annotation$type = {
    .type= {
	.name=			"java/text/Annotation",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x687d454d2df09fc5),
		.source_file=		"Annotation.java",
		.instance_size=		sizeof(_jc_java_text_Annotation$refs) + sizeof(_jc_java_text_Annotation$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_text_Annotation$fields) / sizeof(*_jc_java_text_Annotation$fields),
		.fields=		_jc_java_text_Annotation$fields,
		.num_methods=		sizeof(_jc_java_text_Annotation$methods) / sizeof(*_jc_java_text_Annotation$methods),
		.methods=		_jc_java_text_Annotation$methods,
		.instanceof_hash_table=	_jc_java_text_Annotation$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_text_Annotation$class_depends) / sizeof(*_jc_java_text_Annotation$class_depends),
		.class_depends=		_jc_java_text_Annotation$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_text_Annotation$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_text_Annotation= {
	    .getValue$6f8b281a5ffcc94f=
		&_jc_java_text_Annotation$method$getValue$6f8b281a5ffcc94f,
	    .toString$7ea43b33b80a3070=
		&_jc_java_text_Annotation$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: java/text/Annotation.c <==
// public class java.text.Annotation

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 238a2c0aafd74314 java_lang_VMClass
// @dep_class 312e45ed214d432f java_lang_VMObject
// @dep_class 687d454d2df09fc5 java_text_Annotation

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header java_lang_VMClass
// @dep_header java_lang_VMObject
// @dep_header java_text_Annotation

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "java/lang/VMClass.h"
#include "java/lang/VMObject.h"
#include "java/text/Annotation.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.Object attrib
static _jc_field _jc_java_text_Annotation$field_info$attrib = {
	.name=		"attrib",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_java_text_Annotation$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_java_text_Annotation$object, refs[-1].java_text_Annotation.attrib),
};

// Fields
static _jc_field *const _jc_java_text_Annotation$fields[] = {
	&_jc_java_text_Annotation$field_info$attrib
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object)
//

static _jc_linenum _jc_java_text_Annotation$linenum_table$_init$3fddd28dadb712ab[];

static const unsigned char _jc_java_text_Annotation$param_ptypes$_init$3fddd28dadb712ab[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_text_Annotation$param_types$_init$3fddd28dadb712ab[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_text_Annotation$method_info$_init$3fddd28dadb712ab = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;)V",
	.class=			&_jc_java_text_Annotation$type,
	.param_types=		&_jc_java_text_Annotation$param_types$_init$3fddd28dadb712ab,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_text_Annotation$param_ptypes$_init$3fddd28dadb712ab,
	.signature_hash=	_JC_JLONG(0x3fddd28dadb712ab),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_text_Annotation$method$_init$3fddd28dadb712ab,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_text_Annotation$linenum_table$_init$3fddd28dadb712ab
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_text_Annotation, _init$3fddd28dadb712ab);

void _JC_JCNI_ATTR
_jc_java_text_Annotation$method$_init$3fddd28dadb712ab(_jc_env *const env, _jc_java_text_Annotation$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_java_text_Annotation$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(77);				// 0
	_JC_REF_FIELD(env, r0, java_text_Annotation, attrib) = r1;
	_JC_LINE_NUMBER(78);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object getValue()
//

static _jc_linenum _jc_java_text_Annotation$linenum_table$getValue$6f8b281a5ffcc94f[];

static const unsigned char _jc_java_text_Annotation$param_ptypes$getValue$6f8b281a5ffcc94f[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_text_Annotation$method_info$getValue$6f8b281a5ffcc94f = {
	.name=			"getValue",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_java_text_Annotation$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_text_Annotation$param_ptypes$getValue$6f8b281a5ffcc94f,
	.signature_hash=	_JC_JLONG(0x6f8b281a5ffcc94f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_text_Annotation$method$getValue$6f8b281a5ffcc94f,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_text_Annotation$vtable, java_text_Annotation.getValue$6f8b281a5ffcc94f) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_text_Annotation$linenum_table$getValue$6f8b281a5ffcc94f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_text_Annotation, getValue$6f8b281a5ffcc94f);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_java_text_Annotation$method$getValue$6f8b281a5ffcc94f(_jc_env *const env, _jc_java_text_Annotation$object *this)
{
	struct _jc_java_text_Annotation$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(95);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_text_Annotation, attrib);
	return r1;
}

//
// public java.lang.String toString()
//

static _jc_linenum _jc_java_text_Annotation$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_java_text_Annotation$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_text_Annotation$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_text_Annotation$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_text_Annotation$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_text_Annotation$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_text_Annotation$vtable, java_text_Annotation.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_text_Annotation$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_text_Annotation, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_java_text_Annotation$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_java_text_Annotation$object *this)
{
	struct _jc_java_text_Annotation$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_String$object *r2;
	struct _jc_java_lang_Object$object *r3;
	struct _jc_java_lang_Class$object *r4;
	struct _jc_java_lang_String$object *r5;
	struct _jc_java_lang_String$object *r6;
	_jc_char_array *r7;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(109);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r7 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r7;
	r4 = _JC_INVOKE_STATIC(env, java_lang_VMObject, getClass$2be11d215bfbfbfe, 0, r0);
	_JC_EXPLICIT_NULL_CHECK(env, r4);
	r5 = _JC_INVOKE_STATIC(env, java_lang_VMClass, getName$7a04fe8e1a654d36, 0, r4);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r5);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "[value="));
	r3 = _JC_REF_FIELD(env, r0, java_text_Annotation, attrib);
	r2 = _JC_INVOKE_VIRTUAL(env, java_lang_Object, toString$7ea43b33b80a3070, r3);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r2);
	r1 = _JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$9450b16e89f0618d, 0, r1, 93);
	r6 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r6, r1);
	return r6;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_text_Annotation$methods[] = {
	&_jc_java_text_Annotation$method_info$_init$3fddd28dadb712ab,
	&_jc_java_text_Annotation$method_info$getValue$6f8b281a5ffcc94f,
	&_jc_java_text_Annotation$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_text_Annotation$instanceof_hash_bucket_69[] = {
	&_jc_java_text_Annotation$type,
	_JC_NULL
};
static _jc_type *const _jc_java_text_Annotation$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_text_Annotation$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[69]=	_jc_java_text_Annotation$instanceof_hash_bucket_69,
	[101]=	_jc_java_text_Annotation$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_text_Annotation$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
	{ "java/lang/VMClass",	_JC_JLONG(0x238a2c0aafd74314) },
	{ "java/lang/VMObject",	_JC_JLONG(0x312e45ed214d432f) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_text_Annotation$vtype _jc_java_text_Annotation$type = {
    .type= {
	.name=			"java/text/Annotation",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x687d454d2df09fc5),
		.source_file=		"Annotation.java",
		.instance_size=		sizeof(_jc_java_text_Annotation$refs) + sizeof(_jc_java_text_Annotation$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_text_Annotation$fields) / sizeof(*_jc_java_text_Annotation$fields),
		.fields=		_jc_java_text_Annotation$fields,
		.num_methods=		sizeof(_jc_java_text_Annotation$methods) / sizeof(*_jc_java_text_Annotation$methods),
		.methods=		_jc_java_text_Annotation$methods,
		.instanceof_hash_table=	_jc_java_text_Annotation$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_text_Annotation$class_depends) / sizeof(*_jc_java_text_Annotation$class_depends),
		.class_depends=		_jc_java_text_Annotation$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_text_Annotation$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_text_Annotation= {
	    .getValue$6f8b281a5ffcc94f=
		&_jc_java_text_Annotation$method$getValue$6f8b281a5ffcc94f,
	    .toString$7ea43b33b80a3070=
		&_jc_java_text_Annotation$method$toString$7ea43b33b80a3070,
	},
    }
};
